@@ -1,23 +1,24 @@
 from typing import Type, Optional, Set, List, Tuple, Union
 
 import typing_inspect
+from marshy.utils import resolve_forward_refs
 
 from schemey.array_schema import ArraySchema
-from schemey.factory.schema_factory_abc import SchemaFactoryABC, T
+from schemey.factory.schema_factory_abc import SchemaFactoryABC
 from schemey.schema_abc import SchemaABC
-from schemey.schema_context import SchemaContext
+from schemey.json_schema_context import JsonSchemaContext
 
 
 class ArraySchemaFactory(SchemaFactoryABC):
 
-    def create(self, type_: Type, default_value, context: SchemaContext) -> Optional[SchemaABC]:
+    def create(self, type_: Type, json_context: JsonSchemaContext) -> Optional[SchemaABC]:
         array_type = self.get_array_type(type_)
         if array_type:
             args = typing_inspect.get_args(type_)
-            schema = context.get_schema(args[0])
+            item_type = resolve_forward_refs(args[0])
+            schema = json_context.get_schema(item_type)
             uniqueness = array_type is Set
-            return ArraySchema[T](item_schema=schema, default_value=default_value, item_type_=type_,
-                                  uniqueness=uniqueness)
+            return ArraySchema(item_schema=schema, uniqueness=uniqueness)
 
     @staticmethod
     def get_array_type(type_: Type) -> Union[Type[List], Type[Set], Type[Tuple], None]:
