@@ -3,10 +3,10 @@ from functools import total_ordering
 from typing import TypeVar, Type, Optional
 
 from schemey.schema_abc import SchemaABC
-from schemey.schema_context import SchemaContext
 
 T = TypeVar('T')
 NONE_TYPE = type(None)
+_JsonSchemaContext = 'schemey.json_schema_context.JsonSchemaContext'
 
 
 @total_ordering
@@ -17,9 +17,9 @@ class SchemaFactoryABC(ABC):
         return 100
 
     @abstractmethod
-    def create(self, type_: Type[T], default_value: Optional[T], context: SchemaContext) -> Optional[SchemaABC[T]]:
+    def create(self, type_: Type, json_context: _JsonSchemaContext) -> Optional[SchemaABC]:
         """
-        Create a schemey for the type given, or return None if that was not possible
+        Create a schema for the type given, or return None if that was not possible
         """
 
     def __ne__(self, other):
